==> django-docopt-command-0.1.0.tar.gz: django-docopt-command-0.1.0/django_docopt_command/command.py <==
"""
Use docopt to specify the options of a Django command.

class MyCommand(DocOptCommand):
    docs = "Usage: my_command abc def"

    def handle_docopt(self, arguments):
        pass
"""
import os
import sys
import traceback

from docopt import docopt

from django.core.management import BaseCommand

try:
    from django.core.management.base import OutputWrapper
except ImportError:
    OutputWrapper = None


class DocOptCommand(BaseCommand):
    docs = ''  # please override

    def handle_docopt(self, arguments):
        # please override
        pass

    def print_help(self, prog_name, subcommand):
        sys.stdout.write(self.docs)

    def run_from_argv(self, argv):
        arguments = docopt(self.docs, argv[2:])

        self._handle_default_options(arguments)

        try:
            self.execute(*[], **arguments)
        except Exception as e:
            if not OutputWrapper:
                # Django 1.4
                raise
            else:
                # Django 1.5+
                # self.stderr is not guaranteed to be set here
                stderr = getattr(self, 'stderr', OutputWrapper(sys.stderr, self.style.ERROR))
                if getattr(arguments, 'traceback', False):
                    stderr.write(traceback.format_exc())
                else:
                    stderr.write('%s: %s' % (e.__class__.__name__, e))
                sys.exit(1)

    def _handle_default_options(self, arguments):
        if hasattr(arguments, 'settings'):
            os.environ['DJANGO_SETTINGS_MODULE'] = arguments['settings']

        if hasattr(arguments, 'pythonpath'):
            sys.path.insert(0, arguments['pythonpath'])

    def handle(self, *args, **options):
        return self.handle_docopt(options)

==> django-docopt-command-0.2.2.tar.gz: django-docopt-command-0.2.2/django_docopt_command/command.py <==
"""
Use docopt to specify the options of a Django command.

class MyCommand(DocOptCommand):
    docs = "Usage: my_command abc def"

    def handle_docopt(self, arguments):
        pass
"""
import os
import sys
import traceback

from docopt import docopt

from django.core.management import BaseCommand
from django.core.management.base import OutputWrapper


class DocOptCommand(BaseCommand):
    docs = ''  # please override

    def handle_docopt(self, arguments):
        # please override
        pass

    def print_help(self, prog_name, subcommand):
        sys.stdout.write(self.docs)

    def run_from_argv(self, argv):
        arguments = docopt(self.docs, argv[2:])

        self._handle_default_options(arguments)

        try:
            self.execute(*[], **arguments)
        except Exception as e:
            # self.stderr is not guaranteed to be set here
            stderr = getattr(self, 'stderr', OutputWrapper(sys.stderr, self.style.ERROR))
            if arguments.get('--traceback', False):
                stderr.write(traceback.format_exc())
            else:
                stderr.write('%s: %s' % (e.__class__.__name__, e))
            sys.exit(1)

    def _handle_default_options(self, arguments):
        if arguments.get('settings'):
            os.environ['DJANGO_SETTINGS_MODULE'] = arguments['settings']

        if arguments.get('pythonpath'):
            sys.path.insert(0, arguments['pythonpath'])

    def handle(self, *args, **options):
        return self.handle_docopt(options)
